PropertyConverter class

A utility class to convert the configuration properties into any type.

Constructors

PropertyConverter()
Returns the Singleton instance.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
split(String str, String delimiter, [bool trim = true]) List<String>
toBigInt(Object? value) BigInt
Convert the specified object into a BigInt. Throws ConversionException if the value cannot be converted.
toBool(Object? value) bool
Convert the specified object into a bool. Throws ConversionException if the value cannot be converted.
toDateTime(Object? value) DateTime
Convert the specified object into a DateTime. Throws ConversionException if the value cannot be converted.
toDouble(Object? value) double
Convert the specified object into a int. Throws ConversionException if the value cannot be converted.
toInt(Object? value) int
Convert the specified object into a int. Throws ConversionException if the value cannot be converted.
toIterator(Object? value, String delimiter) Iterator
Returns an iterator over the simple values of a composite value.
toString() String
A string representation of this object.
inherited
toUri(Object? value) Uri
Convert the specified object into a Uri. Throws ConversionException if the value cannot be converted.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance PropertyConverter
Singleton instance
final