getKeys method
Get the list of the keys contained in the configuration. The returned iterator can be used to obtain all defined keys.
Implementation
@override
Iterator<String> getKeys() {
return SubsetIterator(
parentIterator: parent.getKeysPrefixed(prefix),
subsetConfiguration: this);
}